=======
History
=======

0.0.1 (2017-08-09)
------------------

* git init


0.0.2 (2017-08-09)
------------------

* missing manifest file

0.0.3 (2017-08-10)
------------------

* readme changes
* cli splash changes
* make cireqs functions pass python version to docker_execute
* pass timeout param from cli to cireqs
